summaryrefslogtreecommitdiff
path: root/lib/stripslash.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2005-06-02 05:05:29 +0000
committerPaul Eggert <eggert@cs.ucla.edu>2005-06-02 05:05:29 +0000
commitab2edb9e3307a172487bb16edcaf79600bf9ebea (patch)
tree891357990f461f806713fa4cb52c1b9bb91d1ba3 /lib/stripslash.c
parent1e6b9bd047bdaf17291f87e44a218814dd6560f5 (diff)
downloadcoreutils-ab2edb9e3307a172487bb16edcaf79600bf9ebea.tar.xz
Don't use "path" or "filename" to mean "file name"
in comments or local variable names.
Diffstat (limited to 'lib/stripslash.c')
-rw-r--r--lib/stripslash.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/lib/stripslash.c b/lib/stripslash.c
index 1a472f50a..870a66f38 100644
--- a/lib/stripslash.c
+++ b/lib/stripslash.c
@@ -1,5 +1,6 @@
/* stripslash.c -- remove redundant trailing slashes from a file name
- Copyright (C) 1990, 2001, 2003, 2004 Free Software Foundation, Inc.
+
+ Copyright (C) 1990, 2001, 2003, 2004, 2005 Free Software Foundation, Inc.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -21,17 +22,17 @@
#include "dirname.h"
/* Remove trailing slashes from PATH.
Return true if a trailing slash was removed.
- This is useful when using filename completion from a shell that
+ This is useful when using file name completion from a shell that
adds a "/" after directory names (such as tcsh and bash), because
the Unix rename and rmdir system calls return an "Invalid argument" error
- when given a path that ends in "/" (except for the root directory). */
+ when given a file that ends in "/" (except for the root directory). */
bool
-strip_trailing_slashes (char *path)
+strip_trailing_slashes (char *file)
{
- char *base = base_name (path);
+ char *base = base_name (file);
char *base_lim = base + base_len (base);
bool had_slash = (*base_lim != '\0');
*base_lim = '\0';
@@ -21,17 +22,17 @@
#include "dirname.h"
-/* Remove trailing slashes from PATH.
+/* Remove trailing slashes from FILE.
Return true if a trailing slash was removed.